@@ -1,6 +1,6 @@
 # Orca
 #
-# Copyright 2004-2007 Sun Microsystems Inc.
+# Copyright 2004-2008 Sun Microsystems Inc.
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Library General Public
@@ -14,16 +14,16 @@
 #
 # You should have received a copy of the GNU Library General Public
 # License along with this library; if not, write to the
-# Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-# Boston, MA 02111-1307, USA.
+# Free Software Foundation, Inc., Franklin Street, Fifth Floor,
+# Boston MA  02110-1301 USA.
 
 """Uses speech prompts and a command line interface to set Orca
 user preferences."""
 
-__id__        = "$Id: orca_console_prefs.py 2255 2007-04-05 14:33:49Z wwalker $"
-__version__   = "$Revision: 2255 $"
-__date__      = "$Date: 2007-04-05 10:33:49 -0400 (Thu, 05 Apr 2007) $"
-__copyright__ = "Copyright (c) 2005-2007 Sun Microsystems Inc."
+__id__        = "$Id$"
+__version__   = "$Revision$"
+__date__      = "$Date$"
+__copyright__ = "Copyright (c) 2005-2008 Sun Microsystems Inc."
 __license__   = "LGPL"
 
 import re
@@ -33,7 +33,6 @@ import settings
 import speech
 import speechserver
 import orca_prefs
-import platform
 import time
 
 desktopRunning = False
@@ -69,20 +68,20 @@ speechVoiceChoice  = None
 YESEXPR = re.compile(_("^[Yy1]"))
 
 def checkYes(value) :
-     """Checks if a string represents a yes.
+    """Checks if a string represents a yes.
 
-     Arguments:
-     - value: a string read from the console
+    Arguments:
+    - value: a string read from the console
 
-     Returns True if the argument represents a yes
-     """
-     return YESEXPR.match(value) != None
+    Returns True if the argument represents a yes
+    """
+    return YESEXPR.match(value) != None
 
 def sayAndPrint(text,
                 stop=False,
                 getInput=False,
                 speechServer=None,
-                acss=None):
+                voice=None):
     """Prints the given text.  In addition, if the text field
     is not None, speaks the given text, optionally interrupting
     anything currently being spoken.
@@ -92,7 +91,7 @@ def sayAndPrint(text,
     - stop: if True, interrupt any speech currently being spoken
     - getInput: if True, elicits raw input from the user and returns it
     - speechServer: the speech server to use
-    - acss: the ACSS to use for speaking
+    - voice: the ACSS to use for speaking
 
     Returns raw input from the user if getInput is True.
     """
@@ -103,9 +102,9 @@ def sayAndPrint(text,
             speechServer.stop()
 
     if speechServer:
-        speechServer.speak(text, acss)
+        speechServer.speak(text, voice)
     else:
-        speech.speak(text, acss)
+        speech.speak(text, voice)
 
     if getInput:
         return raw_input(text)
@@ -273,7 +272,7 @@ def setupSpeech(prefsDict):
     # range from 0-10 instead of 0-100.
     #
     defaultACSS[acss.ACSS.RATE] = 50
-    defaultACSS[acss.ACSS.GAIN] = 9
+    defaultACSS[acss.ACSS.GAIN] = 100
     defaultACSS[acss.ACSS.AVERAGE_PITCH] = 5
     uppercaseACSS = acss.ACSS({acss.ACSS.AVERAGE_PITCH : 6})
     hyperlinkACSS = acss.ACSS({})
@@ -314,7 +313,8 @@ def setupSpeech(prefsDict):
         # Translators: this is in reference to key echo for
         # normal text entry keys.
         #
-        answer = sayAndPrint(_("Enable alphanumeric and punctuation keys?  Enter y or n: "),
+        answer = sayAndPrint( \
+          _("Enable alphanumeric and punctuation keys?  Enter y or n: "),
                              True,
                              True,
                              speechServerChoice,
@@ -386,18 +386,21 @@ def setupSpeech(prefsDict):
     # has a numeric keypad) and laptop (i.e., small and compact) keyboard
     # layouts for how they might control Orca.
     #
-    sayAndPrint(_("1. Desktop"))
+    sayAndPrint(_("1. Desktop"),
+                False, False, speechServerChoice, speechVoiceChoice)
 
     # Translators: we allow the user to choose between the desktop (i.e.,
     # has a numeric keypad) and laptop (i.e., small and compact) keyboard
     # layouts for how they might control Orca.
     #
-    sayAndPrint(_("2. Laptop"))
+    sayAndPrint(_("2. Laptop"),
+                False, False, speechServerChoice, speechVoiceChoice)
 
     try:
         # Translators: this is prompting for a numerical choice.
         #
-        choice = int(sayAndPrint(_("Enter choice: "), False, True))
+        choice = int(sayAndPrint(_("Enter choice: "),
+                     False, True, speechServerChoice, speechVoiceChoice))
     except:
         choice = -1
     if choice == 2:
@@ -412,26 +415,22 @@ def setupSpeech(prefsDict):
     return True
 
 def logoutUser():
-    """Automatically log the user out of the GNOME desktop."""
+    """Log the user out of the desktop."""
 
-    import gnome
-    import gnome.ui
+    import dbus
+    bus = dbus.SessionBus()
+    sessionManager = bus.get_object('org.gnome.SessionManager',
+                                    '/org/gnome/SessionManager')
+    sessionManager.Logout(dbus.types.UInt32(1))
 
-    gnome.init(platform.package, platform.version)
-    client = gnome.ui.master_client()
-
-    client.request_save(gnome.ui.SAVE_GLOBAL,  # Save style
-                        True,                  # Shutdown
-                        gnome.ui.INTERACT_ANY, # Allow user interaction
-                        False,                 # Fast
-                        True)                  # All apps save state
-
-def showPreferencesUI():
+def showPreferencesUI(commandLineSettings):
     """Uses the console to query the user for Orca preferences."""
 
     prefsDict = {}
 
-    if not setupSpeech(prefsDict):
+    if ("enableSpeech" in commandLineSettings and \
+        not commandLineSettings["enableSpeech"]) or \
+       (not setupSpeech(prefsDict)):
         prefsDict["enableSpeech"]     = False
         prefsDict["enableEchoByWord"] = False
         prefsDict["enableKeyEcho"]    = False
@@ -458,21 +457,34 @@ def showPreferencesUI():
                          speechVoiceChoice)
     prefsDict["enableBrailleMonitor"] = checkYes(answer)
 
+    # Translators: orca can be set up to automatically start when the 
+    # user logs in.
+    #
+    answer = sayAndPrint(_("Automatically start orca when you log in?  " \
+                           "Enter y or n: "),
+                         True,
+                         True,
+                         speechServerChoice,
+                         speechVoiceChoice)
+    settings.setOrcaAutostart(checkYes(answer))
+
     logoutNeeded = orca_prefs.writePreferences(prefsDict)
     if logoutNeeded:
-        sayAndPrint(_("Accessibility support for GNOME has just been enabled. "),
+        sayAndPrint(_("Accessibility support for GNOME has just been enabled."),
                     logoutNeeded,
                     False,
                     speechServerChoice,
                     speechVoiceChoice)
-        sayAndPrint(_("You need to log out and log back in for the change to take effect. "),
+        sayAndPrint( \
+        _("You need to log out and log back in for the change to take effect."),
                     False,
                     False,
                     speechServerChoice,
                     speechVoiceChoice)
 
         if desktopRunning:
-            answer = sayAndPrint(_("Do you want to logout now?  Enter y or n: "),
+            answer = sayAndPrint( \
+                _("Do you want to logout now?  Enter y or n: "),
                                  False,
                                  True,
                                  speechServerChoice,
