@@ -19,9 +19,9 @@
 
 """Custom structural navigation for the Gecko toolkit."""
 
-__id__ = "$Id: structural_navigation.py 4315 2008-11-03 17:25:34Z wwalker $"
-__version__   = "$Revision: 4315 $"
-__date__      = "$Date: 2008-11-03 12:25:34 -0500 (Mon, 03 Nov 2008) $"
+__id__ = "$Id$"
+__version__   = "$Revision$"
+__date__      = "$Date$"
 __copyright__ = "Copyright (c) 2005-2008 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -139,6 +139,12 @@ class GeckoStructuralNavigation(structural_navigation.StructuralNavigation):
     def _presentObject(self, obj, offset):
         """Presents the entire object to the user."""
 
+        if obj.getRole() == pyatspi.ROLE_LINK:
+            try:
+                obj.queryComponent().grabFocus()
+            except:
+                pass
+
         self._script.updateBraille(obj)
         contents = self._script.getObjectContentsAtOffset(obj, offset)
         self._script.speakContents(contents)
